@@ -19,6 +19,8 @@ DEPENDS = ['state']
 class Inventory(Workflow, ModelSQL, ModelView):
     'Stock Inventory'
     __name__ = 'stock.inventory'
+    _rec_name = 'number'
+    number = fields.Char('Number', states=STATES, depends=DEPENDS)
     location = fields.Many2One(
         'stock.location', 'Location', required=True,
         domain=[('type', '=', 'storage')], states={
@@ -76,10 +78,9 @@ class Inventory(Workflow, ModelSQL, ModelView):
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
         super(Inventory, cls).__register__(module_name)
-        cursor = Transaction().cursor
 
         # Add index on create_date
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         table.index_action('create_date', action='add')
 
     @staticmethod
@@ -140,8 +141,17 @@ class Inventory(Workflow, ModelSQL, ModelView):
         Line.cancel_move([l for i in inventories for l in i.lines])
 
     @classmethod
-    def create(cls, values):
-        inventories = super(Inventory, cls).create(values)
+    def create(cls, vlist):
+        pool = Pool()
+        Sequence = pool.get('ir.sequence')
+        Configuration = pool.get('stock.configuration')
+        config = Configuration(1)
+        vlist = [x.copy() for x in vlist]
+        for values in vlist:
+            if values.get('number') is None:
+                values['number'] = Sequence.get_id(
+                    config.inventory_sequence.id)
+        inventories = super(Inventory, cls).create(vlist)
         cls.complete_lines(inventories, fill=False)
         return inventories
 
@@ -161,6 +171,7 @@ class Inventory(Workflow, ModelSQL, ModelView):
         default = default.copy()
         default['date'] = Date.today()
         default['lines'] = None
+        default.setdefault('number')
 
         new_inventories = []
         for inventory in inventories:
@@ -279,7 +290,7 @@ class InventoryLine(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         pool = Pool()
         Move = pool.get('stock.move')
         sql_table = cls.__table__()
@@ -287,7 +298,7 @@ class InventoryLine(ModelSQL, ModelView):
 
         super(InventoryLine, cls).__register__(module_name)
 
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         # Migration from 2.8: Remove constraint inventory_product_uniq
         table.drop_constraint('inventory_product_uniq')
 
