@@ -4,7 +4,7 @@ import datetime
 import operator
 from decimal import Decimal
 from functools import partial
-from collections import OrderedDict
+from collections import OrderedDict, defaultdict
 
 from sql import Literal, Union, Column, Null
 from sql.aggregate import Sum
@@ -18,7 +18,7 @@ from trytond.tools import reduce_ids
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 
-from trytond.modules.product import price_digits
+from trytond.modules.product import price_digits, TemplateFunction
 
 __all__ = ['StockMixin', 'Move']
 
@@ -34,7 +34,7 @@ LOCATION_DOMAIN = [
 LOCATION_DEPENDS = ['state']
 
 
-class StockMixin:
+class StockMixin(object):
     '''Mixin class with helper to setup stock quantity field.'''
 
     @classmethod
@@ -238,6 +238,9 @@ class Move(Workflow, ModelSQL, ModelView):
     unit_price_required = fields.Function(
         fields.Boolean('Unit Price Required'),
         'on_change_with_unit_price_required')
+    assignation_required = fields.Function(
+        fields.Boolean('Assignation Required'),
+        'on_change_with_assignation_required')
 
     @classmethod
     def __setup__(cls):
@@ -299,17 +302,21 @@ class Move(Workflow, ModelSQL, ModelView):
                     },
                 'do': {
                     'invisible': ~Eval('state').in_(['draft', 'assigned']),
+                    'readonly': (Eval('shipment')
+                        | (Eval('assignation_required', True)
+                            & (Eval('state') == 'draft'))),
                     },
                 })
 
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
+        transaction = Transaction()
+        cursor = transaction.connection.cursor()
         sql_table = cls.__table__()
 
         # Migration from 1.2: packing renamed into shipment
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         table.drop_constraint('check_packing')
         for suffix in ('in', 'out', 'in_return', 'out_return', 'internal'):
             old_column = 'packing_%s' % suffix
@@ -327,7 +334,7 @@ class Move(Workflow, ModelSQL, ModelView):
         # Migration from 1.8: fill new field internal_quantity
         if not internal_quantity_exist:
             offset = 0
-            limit = cursor.IN_MAX
+            limit = transaction.database.IN_MAX
             moves = True
             while moves:
                 moves = cls.search([], offset=offset, limit=limit)
@@ -339,11 +346,11 @@ class Move(Workflow, ModelSQL, ModelView):
                             columns=[sql_table.internal_quantity],
                             values=[internal_quantity],
                             where=sql_table.id == move.id))
-            table = TableHandler(cursor, cls, module_name)
+            table = TableHandler(cls, module_name)
             table.not_null_action('internal_quantity', action='add')
 
         # Migration from 1.0 check_packing_in_out has been removed
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         table.drop_constraint('check_packing_in_out')
 
         # Migration from 2.6: merge all shipments
@@ -461,6 +468,11 @@ class Move(Workflow, ModelSQL, ModelView):
             return True
         return False
 
+    @fields.depends('from_location')
+    def on_change_with_assignation_required(self, name=None):
+        if self.from_location:
+            return self.from_location.type == 'storage'
+
     @staticmethod
     def _get_shipment():
         'Return list of Model names for shipment Reference'
@@ -552,7 +564,7 @@ class Move(Workflow, ModelSQL, ModelView):
         qty = Uom.compute_qty(self.uom, quantity, product.default_uom)
 
         qty = Decimal(str(qty))
-        if hasattr(Product, 'cost_price'):
+        if not isinstance(Product.cost_price, TemplateFunction):
             product_qty = product.quantity
         else:
             product_qty = product.template.quantity
@@ -571,7 +583,7 @@ class Move(Workflow, ModelSQL, ModelView):
         else:
             new_cost_price = product.cost_price
 
-        if hasattr(Product, 'cost_price'):
+        if not isinstance(Product.cost_price, TemplateFunction):
             digits = Product.cost_price.digits
             write = partial(Product.write, [product])
         else:
@@ -615,7 +627,7 @@ class Move(Workflow, ModelSQL, ModelView):
         cls.check_origin(moves)
         for move in moves:
             move.set_effective_date()
-            move.save()
+        cls.save(moves)
 
     @classmethod
     @ModelView.button
@@ -626,6 +638,8 @@ class Move(Workflow, ModelSQL, ModelView):
             move.set_effective_date()
             move._do()
             move.state = 'done'
+            # This save() call can't be grouped because the average computation
+            # of product cost price requires each move to be done separately
             move.save()
 
     def _do(self):
@@ -759,7 +773,7 @@ class Move(Workflow, ModelSQL, ModelView):
         Date = pool.get('ir.date')
         Location = pool.get('stock.location')
 
-        Transaction().cursor.lock(cls._table)
+        Transaction().database.lock(Transaction().connection, cls._table)
 
         if with_childs:
             locations = Location.search([
@@ -785,6 +799,9 @@ class Move(Workflow, ModelSQL, ModelView):
                 key += (value,)
             return key
 
+        child_locations = {}
+        to_write = []
+        to_assign = []
         success = True
         for move in moves:
             if move.state != 'draft':
@@ -795,9 +812,12 @@ class Move(Workflow, ModelSQL, ModelView):
             # Keep location order for pick_product
             location_qties = OrderedDict()
             if with_childs:
-                childs = Location.search([
-                        ('parent', 'child_of', [move.from_location.id]),
-                        ])
+                childs = child_locations.get(move.from_location)
+                if childs is None:
+                    childs = Location.search([
+                            ('parent', 'child_of', [move.from_location.id]),
+                            ])
+                    child_locations[move.from_location] = childs
             else:
                 childs = [move.from_location]
             for location in childs:
@@ -816,23 +836,24 @@ class Move(Workflow, ModelSQL, ModelView):
             if move.quantity - picked_qties >= move.uom.rounding:
                 success = False
                 first = False
-                cls.write([move], {
-                    'quantity': Uom.round(
-                            move.quantity - picked_qties, move.uom.rounding),
-                    })
+                values = {
+                    'quantity': move.uom.round(
+                        move.quantity - picked_qties),
+                    }
+                to_write.extend([[move], values])
             else:
                 first = True
             for from_location, qty in to_pick:
                 values = {
                     'from_location': from_location.id,
-                    'quantity': Uom.round(qty, move.uom.rounding),
+                    'quantity': move.uom.round(qty),
                     }
                 if first:
-                    cls.write([move], values)
-                    cls.assign([move])
+                    to_write.extend([[move], values])
+                    to_assign.append(move)
                     first = False
                 else:
-                    cls.assign(cls.copy([move], default=values))
+                    to_assign.extend(cls.copy([move], default=values))
 
                 qty_default_uom = Uom.compute_qty(move.uom, qty,
                         move.product.default_uom, round=False)
@@ -841,6 +862,10 @@ class Move(Workflow, ModelSQL, ModelView):
                 to_key = get_key(move, to_location)
                 pbl[from_key] = pbl.get(from_key, 0.0) - qty_default_uom
                 pbl[to_key] = pbl.get(to_key, 0.0) + qty_default_uom
+        if to_write:
+            cls.write(*to_write)
+        if to_assign:
+            cls.assign(to_assign)
         return success
 
     @classmethod
@@ -1130,30 +1155,35 @@ class Move(Workflow, ModelSQL, ModelView):
         pool = Pool()
         Location = pool.get('stock.location')
         Product = pool.get('product.product')
-        Uom = pool.get('product.uom')
 
         assert query is not None, (
             "Query in Move.compute_quantities() can't be None")
         assert 'product' in grouping
 
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         cursor.execute(*query)
         raw_lines = cursor.fetchall()
 
         product_getter = operator.itemgetter(grouping.index('product') + 1)
         res_product_ids = set()
-        quantities = {}
+        quantities = defaultdict(lambda: 0)
         keys = set()
+        # We can do a quick loop without propagation if the request is for a
+        # single location because all the locations are children and we can sum
+        # them directly.
+        if len(location_ids) == 1:
+            location, = location_ids
         for line in raw_lines:
-            location = line[0]
+            if len(location_ids) > 1:
+                location = line[0]
             key = tuple(line[1:-1])
             quantity = line[-1]
-            quantities[(location,) + key] = quantity
+            quantities[(location,) + key] += quantity
             res_product_ids.add(product_getter(line))
             keys.add(key)
 
         # Propagate quantities on from child locations to their parents
-        if with_childs:
+        if with_childs and len(location_ids) > 1:
             # Fetch all child locations
             locations = Location.search([
                     ('parent', 'child_of', location_ids),
@@ -1199,6 +1229,6 @@ class Move(Workflow, ModelSQL, ModelView):
             location = key[0]
             product = product_getter(key)
             uom = default_uom[product]
-            quantities[key] = Uom.round(quantity, uom.rounding)
+            quantities[key] = uom.round(quantity)
 
         return quantities
